"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileSystem = void 0;
const promises_1 = __importDefault(require("fs/promises"));
const path_1 = __importDefault(require("path"));
const sanitize_filename_1 = __importDefault(require("sanitize-filename"));
class FileSystem {
    constructor(opt) {
        this.opt = opt;
    }
    getPath(kind, story, suffix, extension) {
        const name = this.opt.flat
            ? (0, sanitize_filename_1.default)((kind + '_' + story).replace(/\//g, '_'))
            : kind
                .split('/')
                .map(k => (0, sanitize_filename_1.default)(k))
                .join('/') +
                '/' +
                (0, sanitize_filename_1.default)(story);
        const filePath = path_1.default.join(this.opt.outDir, name + (suffix.length ? `_${suffix.join('_')}` : '') + extension);
        return filePath;
    }
    /**
     *
     * Save captured buffer as a PNG image.
     *
     * @param kind - Story kind
     * @param story - Name of this story
     * @param suffix - File name suffix
     * @param buffer - PNG image buffer to save
     * @returns Absolute file path
     *
     **/
    async saveScreenshot(kind, story, suffix, buffer) {
        const filePath = this.getPath(kind, story, suffix, '.png');
        await promises_1.default.mkdir(path_1.default.dirname(filePath), { recursive: true });
        await promises_1.default.writeFile(filePath, buffer);
        return filePath;
    }
    /**
     *
     * Save captured tracing buffer as a json file.
     *
     * @param kind - Story kind
     * @param story - Name of this story
     * @param suffix - File name suffix
     * @param buffer - PNG image buffer to save
     * @returns Absolute file path
     *
     **/
    async saveTrace(kind, story, suffix, buffer) {
        const filePath = this.getPath(kind, story, [...suffix, 'trace'], '.json');
        await promises_1.default.mkdir(path_1.default.dirname(filePath), { recursive: true });
        await promises_1.default.writeFile(filePath, buffer);
        return filePath;
    }
}
exports.FileSystem = FileSystem;
